CA01-Cl02
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Section |
clickAndWait | link=Añadir section |
type | id_name_es | CA01-Cl02 Section
type | id_slug | ca01-cl02-section
select | id_status | label=Publicado
clickAndWait | _continue |
clickAndWait | link=Ver en el sitio |
verifyTextPresent | Inicio → CA01-Cl02 Section |
verifyTextPresent | CA01-Cl02 Section |
verifyTextPresent | You can edit in here |
clickAndWait | //div[@id='content']/a/span |
select | id_status | label=Borrador
clickAndWait | _continue |
clickAndWait | link=Terminar sesión |
open | / |
verifyTextNotPresent | CA01-Cl02 Section |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Section |
clickAndWait | link=CA01-Cl02 Section |
select | id_status | label=Pendiente
clickAndWait | _continue |
clickAndWait | link=Terminar sesión |
open | / |
verifyTextNotPresent | CA01-Cl02 Section |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Section |
clickAndWait | link=CA01-Cl02 Section |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |